part of model_notifier;

/// Load the provider.
///
/// It is freely available from outside the widget.
///
/// Please specify the provider you want to load in [provider].
Result read<Result>(ProviderBase<Result> provider) {
  // ignore: invalid_use_of_visible_for_testing_member
  final container = providerScopeKey.currentState?.container;
  if (container != null) {
    return container.read(provider);
  }
  throw Exception("Provider scope not found.");
}

/// Gets the key for the date associated with [key].
///
/// If [time] is specified, the key at that time is obtained.
String dailyKey(String key, [DateTime? time]) {
  time ??= DateTime.now();
  return "$key:${time.format("yyyyMMdd")}";
}

/// Gets the key for the week associated with [key].
///
/// If [time] is specified, the key at that time is obtained.
String weeklyKey(String key, [DateTime? time]) {
  time ??= DateTime.now();
  return "$key:${time.format("yyyyww")}";
}

/// Gets the key of the month associated with [key].
///
/// If [time] is specified, the key at that time is obtained.
String monthlyKey(String key, [DateTime? time]) {
  time ??= DateTime.now();
  return "$key:${time.format("yyyyMM")}";
}

/// Gets the key for the year associated with [key].
///
/// If [time] is specified, the key at that time is obtained.
String yearlyKey(String key, [DateTime? time]) {
  time ??= DateTime.now();
  return "$key:${time.format("yyyy")}";
}
